@@ -22,6 +22,7 @@ import logging
 import os
 
 import click
+from rich import print
 from texttable import Texttable
 
 from kodexa.cloud.kodexa import ExtensionHelper, KodexaPlatform
@@ -34,6 +35,24 @@ LOGGING_LEVELS = {
     4: logging.DEBUG,
 }  #: a mapping of `verbose` option counts to logging levels
 
+DEFAULT_COLUMNS = {
+    'extensionPacks': [
+        'orgSlug',
+        'slug',
+        'name',
+        'description',
+        'type',
+        'status'
+    ],
+    'default': [
+        'orgSlug',
+        'slug',
+        'name',
+        'description',
+        'type'
+    ]
+}
+
 
 class Info(object):
     """An information object to pass data between CLI functions."""
@@ -74,15 +93,26 @@ def cli(info: Info, verbose: int):
 
 @click.option('--path', default=os.getcwd(), help='Path to folder containing kodexa.yml')
 @click.option('--url', default=KodexaPlatform.get_url(), help='The URL to the Kodexa server')
+@click.option('--org', help='The slug for the organization to deploy to')
 @click.option('--token', default=KodexaPlatform.get_access_token(), help='Access token')
 @cli.command()
 @pass_info
-def deploy(_: Info, path: str, url: str, token: str):
+def deploy(_: Info, path: str, url: str, org: str, token: str):
     """Deploy extension pack to an Kodexa platform instance"""
-    metadata = ExtensionHelper.load_metadata(path)
+
+    print("Starting deployment from path", path)
     KodexaPlatform.set_url(url)
     KodexaPlatform.set_access_token(token)
-    KodexaPlatform.deploy_extension(metadata)
+
+    if '://' in path:
+        print("Deploying from URI", path)
+        KodexaPlatform.deploy_extension_from_uri(path, org)
+    else:
+        print("Deploying local metadata from", path)
+        metadata = ExtensionHelper.load_metadata(path)
+        metadata['orgSlug'] = org;
+        KodexaPlatform.deploy_extension(metadata)
+    print("Deployed extension")
 
 
 @cli.command()
@@ -92,21 +122,42 @@ def deploy(_: Info, path: str, url: str, token: str):
 @click.option('--token', default=KodexaPlatform.get_access_token(), help='Access token')
 @pass_info
 def get(_: Info, object_type: str, organization_slug: str, url: str, token: str):
-    """Deploy extension pack to an Kodexa platform instance"""
+    """List the instance of the object type"""
     KodexaPlatform.set_url(url)
     KodexaPlatform.set_access_token(token)
     objects = KodexaPlatform.list_objects(organization_slug, object_type)
-    table = Texttable().header(['org', 'slug', 'name', 'description', 'type'])
-    for object_dict in objects['content']:
-        table.add_row([
-            object_dict['orgSlug'],
-            object_dict['slug'],
-            object_dict['name'] if 'name' in object_dict else '',
-            object_dict['description'] if 'description' in object_dict else '',
-            object_dict['type'],
-        ])
 
-    print(table.draw() + "\n")
+    cols = DEFAULT_COLUMNS['default']
+
+    if object_type in DEFAULT_COLUMNS:
+        cols = DEFAULT_COLUMNS[object_type]
+
+    table = Texttable().header(cols)
+    for object_dict in objects['content']:
+        row = []
+
+        for col in cols:
+            row.append(object_dict[col] if col in object_dict else '')
+
+        table.add_row(row)
+
+    click.echo(table.draw() + "\n")
+
+
+@cli.command()
+@click.argument('object_type')
+@click.argument('organization_slug')
+@click.argument('slug')
+@click.option('--url', default=KodexaPlatform.get_url(), help='The URL to the Kodexa server')
+@click.option('--token', default=KodexaPlatform.get_access_token(), help='Access token')
+@pass_info
+def delete(_: Info, object_type: str, organization_slug: str, slug: str, url: str, token: str):
+    """Delete object from the platform"""
+    print(f"Deleting {object_type} {slug} in organization {organization_slug}")
+    KodexaPlatform.set_url(url)
+    KodexaPlatform.set_access_token(token)
+    KodexaPlatform.delete_object(organization_slug, slug, object_type)
+    click.echo(f"Deleted {object_type} {organization_slug}/{slug}")
 
 
 @cli.command()
@@ -115,3 +166,16 @@ def get(_: Info, object_type: str, organization_slug: str, url: str, token: str)
 def metadata(_: Info, path: str):
     """Load metadata"""
     metadata = ExtensionHelper.load_metadata(path)
+    print(f"Metadata loaded")
+
+
+@cli.command()
+@click.option('--path', default=os.getcwd(), help='Path to folder container kodexa.yml')
+@pass_info
+def document(_: Info, path: str):
+    """Load metadata"""
+    metadata = ExtensionHelper.load_metadata(path)
+    print("[green]Metadata loaded :tada: [/green]")
+    from kodexa.cli.documentation import generate_documentation
+    generate_documentation(metadata)
+    print("[green]Documentation has been successfully built[/green]")
