@@ -4,4 +4,4 @@ Kodexa Platform
 
 Provides out of the box integration with the Kodexa paltform, enabling the universe of content services that are available
 """
-from .kodexa import KodexaSession, KodexaPipeline, KodexaAction, KodexaPlatform
+from .kodexa import RemoteSession, RemotePipeline, RemoteAction, KodexaPlatform
