@@ -105,6 +105,17 @@ class KodexaPlatform:
             logger.error(response.text)
             raise Exception("Unable to deploy new extension")
 
+    @staticmethod
+    def deploy_extension_from_uri(path, organisation_slug):
+        response = requests.post(f"{KodexaPlatform.get_url()}/api/extensionPacks/{organisation_slug}?uri={path}",
+                                 headers={"x-access-token": KodexaPlatform.get_access_token(),
+                                          "content-type": "application/json"})
+        if response.status_code == 200:
+            logger.info("Extension deployed")
+        else:
+            logger.error(response.text)
+            raise Exception("Unable to deploy new extension")
+
     @staticmethod
     def deploy(slug: str, pipeline: Pipeline, name: str = "A new pipeline", description: str = "A Kodexa Pipeline",
                example_urls=None, more_info_url: str = None, force_replace=False,
@@ -206,6 +217,15 @@ class KodexaPlatform:
             logger.error(response.text)
             raise Exception("Unable to undeploy and replace existing pipeline")
 
+    @staticmethod
+    def delete_object(organization_slug, slug, object_type):
+        delete_response = requests.delete(f"{KodexaPlatform.get_url()}/api/{object_type}/{organization_slug}/{slug}",
+                                          headers={"x-access-token": KodexaPlatform.get_access_token(),
+                                                   "content-type": "application/json"})
+        if delete_response.status_code != 200:
+            logger.error(delete_response.text)
+            raise Exception("Unable to list objects")
+
 
 class RemoteSession:
     """
@@ -496,6 +516,7 @@ class ExtensionHelper:
 
     @staticmethod
     def load_metadata(path):
+
         if os.path.exists(os.path.join(path, 'dharma.json')):
             dharma_metadata_file = open(os.path.join(path, 'dharma.json'))
             dharma_metadata = Dict(json.loads(dharma_metadata_file.read()))
@@ -507,5 +528,4 @@ class ExtensionHelper:
             dharma_metadata = Dict(yaml.safe_load(dharma_metadata_file.read()))
         else:
             raise Exception("Unable to find a kodexa.yml file describing your extension")
-
         return dharma_metadata
