@@ -2,11 +2,13 @@ import itertools
 import json
 import re
 import uuid
+from dataclasses import dataclass, field
 from enum import Enum
 from typing import List, Optional, Any
 
 import msgpack
 from addict import Dict
+from dataclasses_json import dataclass_json
 
 from kodexa.mixins import registry
 
@@ -1160,8 +1162,21 @@ class DocumentRender:
         return self.kodexa_render.build_html(self.document, node)
 
 
+@dataclass
+@dataclass_json
 class SourceMetadata(object):
-    pass
+    """
+    Class for keeping track of the original source information for a
+    document
+    """
+    original_filename: Optional[str] = None
+    original_path: Optional[str] = None
+    checksum: Optional[str] = None
+    last_modified: Optional[str] = None
+    created: Optional[str] = None
+    connector: Optional[str] = None
+    mime_type: Optional[str] = None
+    headers: dict = field(default_factory=dict)
 
 
 class Document(object):
@@ -1399,8 +1414,8 @@ class Document(object):
         :rtype: Document
         """
         file_document = Document()
-        file_document.metadata.connector = 'file-handle'
-        file_document.metadata.connector_options.file = file
+        file_document.source.connector = 'file-handle'
+        file_document.source.original_path = file
         return file_document
 
     @classmethod
@@ -1417,9 +1432,9 @@ class Document(object):
         if headers is None:
             headers = {}
         url_document = Document()
-        url_document.metadata.connector = 'url'
-        url_document.metadata.connector_options.url = url
-        url_document.metadata.connector_options.headers = headers
+        url_document.source.connector = 'url'
+        url_document.source.original_path = url
+        url_document.source.headers = headers
         return url_document
 
     def select(self, selector, variables={}):
